@@ -104,9 +104,8 @@ class CommentDetailsForm(CommentSecurityForm):
     """
     #text = forms.CharField(label=_('Comment'), widget=forms.Textarea, max_length=COMMENT_MAX_LENGTH)
     text = forms.CharField(
-        widget=forms.Textarea,
+        widget=forms.Textarea(attrs={'tabindex': '1', 'placeholder': COMMENT_PLACEHOLDER}),
         max_length=COMMENT_MAX_LENGTH,
-        attrs={'tabindex': '1', 'placeholder': COMMENT_PLACEHOLDER}
     )
 
     def get_comment_object(self):
